@@ -1,10 +1,8 @@
-from typing import List, Tuple
+from typing import Callable, List, Tuple
 
 from gensim.models.keyedvectors import Word2VecKeyedVectors
 import numpy as np
 
-from swem import tokenizers
-
 
 def _word_embed(
     token: str,
@@ -14,7 +12,7 @@ def _word_embed(
     """ Get word embedding of given token.
 
     Args:
-        token (str): A word token to embed.
+        token (str): A word token to get embed.
         kv (Word2VecKeyedVectors): Vocabularies dictionary.
         uniform_range (Tuple[float, ...]): A range of uniform distribution to
                                            generate random vector.
@@ -26,7 +24,7 @@ def _word_embed(
         return kv[token]
     except Exception as e:
         print(e)
-        embed_dim = kv.vector_size
+        embed_dim: int = kv.vector_size
         return np.random.uniform(
             uniform_range[0],
             uniform_range[1],
@@ -45,7 +43,7 @@ def _word_embeds(tokens: List[str], kv: Word2VecKeyedVectors,
         numpy.ndarray: An embedding array with shape
                        (token_size, self.embed_dim, ).
     """
-    doc_embed = []
+    doc_embed: List[np.ndarray] = []
     for token in tokens:
         word_embed: np.ndarray = _word_embed(
             token=token, kv=kv, uniform_range=uniform_range
@@ -63,21 +61,14 @@ class SWEM:
             Callable object to tokenize input text.
         uniform_range: Tuple[float, ...]
             A range of uniform distribution to create random embedding.
-        lang (str): 'ja' or `en`. Default value is 'ja'.
     """
 
-    def __init__(self, kv, tokenizer=None, uniform_range=(-0.01, 0.01),
-                 lang: str = 'ja'):
-        self.kv = kv
-        if tokenizer is None:
-            if lang == 'ja':
-                tokenizer = tokenizers.tokenize_ja
-            elif lang == 'en':
-                tokenizer = tokenizers.tokenize_en
-            else:
-                msg = f'Argument [lang] does not support: "{lang}".'
-                raise ValueError(msg)
-        self.tokenizer = tokenizer
+    def __init__(self, kv, tokenizer: Callable, uniform_range=(-0.01, 0.01)):
+        self.kv: Word2VecKeyedVectors = kv
+
+        if not callable(tokenizer):
+            raise ValueError('tokenizer must be callable object.')
+        self.tokenizer: Callable = tokenizer
         self.uniform_range: Tuple[float, ...] = uniform_range
 
     @staticmethod
@@ -143,6 +134,6 @@ class SWEM:
             return self._hierarchical_pool(doc_embed, n_windows)
 
         else:
-            raise AttributeError(
+            raise ValueError(
                 f'infer_vector has no attribute [{method}] method.'
             )
